<?php

namespace App\Http\Controllers\Profiling;

use Spatie\Permission\Models\Role;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Gate;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;

use App\Models\Patient;
use App\Models\Dosage;
use App\Models\Counter;
use App\Models\Branch;
use DataTables;

use Brian2694\Toastr\Facades\Toastr;

class PatientController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         //$this->middleware('permission:role-list|role-create|role-edit|role-delete', ['only' => ['index','store']]);
         $this->middleware('permission:Patient-list|Patient-show', ['only' => ['index','show']]);
         $this->middleware('permission:Patient-list', ['only' => ['show']]);
         $this->middleware('permission:Patient-create', ['only' => ['create','store']]);
         $this->middleware('permission:Patient-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:Patient-delete', ['only' => ['destroy']]);
         $this->middleware('permission:Patient-import', ['only' => ['importExportView']]);
    }

    public function index(Request $request)
    {

         if(request()->ajax())
         {
              if( !empty($request->patientno) || !empty($request->name) || !empty($request->mobileno))
              {

                $query = DB::table('patients');

                if(!empty($request->patientno)) {
                    $query = $query->where('patientno', 'LIKE',"%{$request->patientno}%");
                };

                if(!empty($request->name)) {
                    $query = $query->where('patients.fullname', 'LIKE',"%{$request->name}%");
                };

                if(!empty($request->mobileno)) {
                    $query = $query->where('patients.mobileno', 'LIKE',"%{$request->mobileno}%");
                };

                $data= $query->get(); 
                //$data= $query; 

              }
              else
              {
               $data = DB::table('patients')
                 ->get();
              }

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {
                $show = route('profiling.patients.show',$row->id);
                $edit =  route('profiling.patients.edit',$row->id);
                $delete =  route('profiling.patients.destroy',$row->id);
                $token =  csrf_token();                  
                //return "<a href='{$show}' class='btn btn-xs btn-primary'><i class='glyphicon glyphicon-edit'></i> Edit</a>";
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='{$show}'><i class='fas fa-desktop text-blue'></i><small> View</small></a>
                              <a class='dropdown-item' href='{$edit}'><i class='fas fa-edit text-green'></i><small> Edit</small></a>
                              <form action='{$delete}' name='deleteform' method='POST' onsubmit=\"return confirm('Are you sure you want to Delete Selected Record?');\" style='display: inline-block;'>".
                               "<input type='hidden' name='_method' value='DELETE'>".
                               "<input type='hidden' name='_token' value='{$token}'>". 
                               "<button type='submit' title = 'Delete' class='dropdown-item' style='border:none; background:none; cursor:pointer;'><i class='fa fa-trash text-red'></i><small> Delete</small></button>".
                               "</form>
                            </div>
                        </div>";   
                
            })
            ->removeColumn('password')

            ->make(true);


             // return datatables()->of($data)->make(true);
    


         }


        return view('profiling.patients.index');

              
         
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('profiling.patients.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Patient $patients)
    {

        if($counters = DB::table('counters')->where('appname', 'patients')->first()){
            $appyear = $counters->appyear;
            $appctr = $counters->appctr;
            $curyear = date('y');

            if($appyear == $curyear){
                $appctr = $appctr + 1;
                $controlno = $appyear. "-". str_pad($appctr, 6, "0", STR_PAD_LEFT);
                $counters = Counter::where('appname', '=', "patients")->first();
                $counters->appyear = $appyear;
                $counters->appctr = $appctr;
                $counters->save();
            } else {
                $appctr = 1;
                $controlno = $curyear. "-". str_pad($appctr, 6, "0", STR_PAD_LEFT);
                $counters = Counter::where('appname', '=', "patients")->first();
                $counters->appyear = $curyear;
                $counters->appctr = $appctr;
                $counters->save();
            }
        } else {
            $curyear = date('y');
            $appctr = 1;
            $controlno = $curyear. "-". str_pad($appctr, 6, "0", STR_PAD_LEFT);
            $counters = new Counter; 
            $counters->appname = "patients";
            $counters->appyear = $curyear;
            $counters->appctr = $appctr;
            $counters->save();
        }

        $patients->patientno = $controlno;


        $patients->lname = $request->lname; 
        $patients->fname = $request->fname;
        $patients->mname = $request->mname;
        if(!empty($request->mname)){
            $patients->fullname = $request->fname. " ". substr($request->mname, 0, 1). ". ". $request->lname;
            $patients->fullname2 = $request->lname. ", ". $request->fname. " ". substr($request->mname, 0, 1). ".";            
        } else {
            $patients->fullname = $request->fname. " ". $request->lname;
            $patients->fullname2 = $request->lname. ", ". $request->fname;            
        }


        $patients->address = $request->address;
        $patients->gender = $request->gender;
        $patients->mobileno = $request->mobileno;
        $patients->telno = $request->telno;
        $patients->emailadd = $request->emailadd;
        if(!empty($request->birthdate)){
            $patients->birthdate = $request->birthdate;
        }
        $patients->allergies = $request->allergies;
        $patients->conditions = $request->conditions;
        $patients->scidno = $request->scidno;
        $patients->save();

        return redirect()->route('profiling.patients.index'); 
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $patients = Patient::where('id', '=', $id)->first();
        $branches = Branch::orderBy('branch', 'ASC')->get()->all();

        return view('profiling.patients.show', compact('patients', 'branches')); 
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

        $patients = Patient::where('id', '=', $id)->first();


        return view('profiling.patients.edit', compact('patients')); 
        
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $patients = Patient::where('id', '=', $id)->first(); 
        $patients->lname = $request->lname; 
        $patients->fname = $request->fname;
        $patients->mname = $request->mname;
        if(!empty($request->mname)){
            $patients->fullname = $request->fname. " ". substr($request->mname, 0, 1). ". ". $request->lname;
            $patients->fullname2 = $request->lname. ", ". $request->fname. " ". substr($request->mname, 0, 1). ".";            
        } else {
            $patients->fullname = $request->fname. " ". $request->lname;
            $patients->fullname2 = $request->lname. ", ". $request->fname;            
        }

        $patients->address = $request->address;
        $patients->gender = $request->gender;
        $patients->mobileno = $request->mobileno;
        $patients->telno = $request->telno;
        $patients->emailadd = $request->emailadd;
        if(!empty($request->birthdate)){
            $patients->birthdate = $request->birthdate;
        }
        $patients->allergies = $request->allergies;
        $patients->conditions = $request->conditions;
        $patients->scidno = $request->scidno;
        $patients->save();

        return redirect()->route('profiling.patients.index'); 
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function fetctpatpurchases(Request $request)
    {

         if(request()->ajax())
         {
              if( !empty($request->patientno) || !empty($request->branchid))
              {

                $query = DB::table('purchases');
                $query = $query->select('purchases.*', 'patients.fullname', 'branches.branch');
                $query = $query->leftJoin('patients', 'patients.patientno', '=', 'purchases.patientno');
                $query = $query->leftJoin('branches', 'branches.branchid', '=', 'purchases.branchid');

                if(!empty($request->patientno)) {
                    $query = $query->where('purchases.patientno', 'LIKE',"%{$request->patientno}%");
                };

                if(!empty($request->branchid)) {
                    $query = $query->where('purchases.branchid', '=', $request->branchid);
                };

                $data= $query->get(); 
                //$data= $query; 

              }
              else
              {
                $query = DB::table('purchases');
                $query = $query->select('purchases.*', 'patients.fullname', 'branches.branch');
                $query = $query->leftJoin('patients', 'patients.patientno', '=', 'purchases.patientno');
                $query = $query->leftJoin('branches', 'branches.branchid', '=', 'purchases.branchid');
                $data= $query->get(); 
              }

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {

                $token =  csrf_token();                  
                //return "<a href='{$show}' class='btn btn-xs btn-primary'><i class='glyphicon glyphicon-edit'></i> Edit</a>";
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='#' onclick='ViewPurchaseTrans(this)' id='$row->purchaseid' data-bs-toggle='modal' data-bs-target='#viewpurchasesmodal'><i class='fas fa-desktop text-blue'></i><small> View</small></a>
                            </div>
                        </div>";   
                
            })
            ->removeColumn('password')
            ->make(true);

         }


        //return view('profiling.transactions.index', compact('branches', 'curbranch'));
         
    }


    public function fetchpatpurchasetrans(Request $request)
    {

        $purchaseid = $request->purchaseid;
        if(request()->ajax())
        {
              $userid = auth()->user()->id;
               $data = DB::table('purchasetrans')
                 ->select('*')
                 ->where('purchaseid', '=',$purchaseid)
                 ->get();

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {
                
                $token =  csrf_token();                  
                //return "<a title='Delete' href='#' onclick='EditDependent()' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-edit'></i> Delete</a> 
                //        <a title='Delete' href='#' onclick='DeleteDependent(this)' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";
                //return "<a title='Delete' href='#' onclick='DeleteCertification(this)' type='button' class='btn btn-xs btn-danger' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";    
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='#' onclick='ViewPurchaseTrans(this)' id='$row->id' data-bs-toggle='modal' data-bs-target='#viewpurchasesmodal'><i class='fas fa-desktop text-blue'></i><small> View</small></a>
                            </div>
                        </div>";                 
                
            })
            ->editColumn('id', 'ID: {{$id}}')            
            ->removeColumn('password')
            ->make(true);

        }

    }  

}
