<?php

namespace App\Http\Controllers\Profiling;

use Spatie\Permission\Models\Role;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Gate;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;

use Mail;

use App\Models\Patient;
use App\Models\Patbranch;
use App\Models\Branch;
use App\Models\Dosage;
use App\Models\Counter;
use App\Models\Prescription;
use App\Models\Purchase;
use App\Models\Purchasetran;
use App\Models\Purchasetemp;
use App\Models\Reminder;
use DataTables;

use Brian2694\Toastr\Facades\Toastr;

class TransactionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    function __construct()
    {
         //$this->middleware('permission:role-list|role-create|role-edit|role-delete', ['only' => ['index','store']]);
         $this->middleware('permission:Transactions-list|Transactions-show', ['only' => ['index','show']]);
         $this->middleware('permission:Transactions-list', ['only' => ['show']]);
         $this->middleware('permission:Transactions-create', ['only' => ['create','store']]);
         $this->middleware('permission:Transactions-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:Transactions-delete', ['only' => ['destroy']]);
         $this->middleware('permission:Transactions-import', ['only' => ['importExportView']]);
    }

    public function index(Request $request)
    {

         if(request()->ajax())
         {
              if( !empty($request->patientno) || !empty($request->fullname) || !empty($request->branchid) || !empty($request->datefrom) || !empty($request->dateto))
              {

                $query = DB::table('purchases');
                $query = $query->select('purchases.*', 'patients.fullname', 'branches.branch');
                $query = $query->leftJoin('patients', 'patients.patientno', '=', 'purchases.patientno');
                $query = $query->leftJoin('branches', 'branches.branchid', '=', 'purchases.branchid');

                if(!empty($request->patientno)) {
                    $query = $query->where('purchases.patientno', 'LIKE',"%{$request->patientno}%");
                };

                if(!empty($request->fullname)) {
                    $query = $query->where('patients.fullname', 'LIKE',"%{$request->fullname}%");
                };

                if(!empty($request->branchid)) {
                    $query = $query->where('purchases.branchid', '=', $request->branchid);
                };
                if(!empty($request->datefrom)) {
                    $query = $query->where('purchases.transdate', '>=', $request->datefrom);
                };
                if(!empty($request->dateto)) {
                    $query = $query->where('purchases.transdate', '<=', $request->dateto);
                };                

                $data= $query->get(); 
                //$data= $query; 

              }
              else
              {
                $query = DB::table('purchases');
                $query = $query->select('purchases.*', 'patients.fullname', 'branches.branch');
                $query = $query->leftJoin('patients', 'patients.patientno', '=', 'purchases.patientno');
                $query = $query->leftJoin('branches', 'branches.branchid', '=', 'purchases.branchid');
                $data= $query->get(); 
              }

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {
                $show = route('profiling.transactions.show',$row->purchaseid);
                $edit =  route('profiling.transactions.edit',$row->purchaseid);
                $delete =  route('profiling.transactions.destroy',$row->purchaseid);
                $token =  csrf_token();                  
                //return "<a href='{$show}' class='btn btn-xs btn-primary'><i class='glyphicon glyphicon-edit'></i> Edit</a>";
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='{$show}'><i class='fas fa-desktop text-blue'></i><small> View</small></a>
                            </div>
                        </div>";   
                
            })
            ->removeColumn('password')

            ->make(true);


             // return datatables()->of($data)->make(true);
    


         }

        $branches = Branch::orderBy('branch', 'ASC')->get()->all();
        $branchid = auth()->user()->branchid;
        $curbranch = Branch::where('branchid', $branchid)->first();


        return view('profiling.transactions.index', compact('branches', 'curbranch'));

              
         
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $dosages = Dosage::orderBy('id', 'ASC')->get()->all();
        return view('profiling.transactions.create', compact('dosages'));

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Purchase $purchases)
    {
        $userid = auth()->user()->id;
        $transdate = date('Y-m-d');
        $transtime = date('h:i:s');
        $branchid = auth()->user()->branchid;
        $purchases->patientno = $request->vpatientno;
        $purchases->transdate = $transdate;
        $purchases->transtime = $transtime;
        $purchases->branchid = $branchid;
        $purchasetemps = DB::table('purchasetemps')->where('userid','=', $userid)->get();
        $totalqty = $purchasetemps->sum('qty');
        $purchases->totalqty = $totalqty;
        $purchases->save();
        $purchaseid = $purchases->purchaseid;
        $patients = DB::table('patients')->where('patientno','=', $request->vpatientno)->first();

        foreach($purchasetemps as $purchasetemps){
          $purchasetrans = new Purchasetran;
          $purchasetrans->purchaseid = $purchaseid;
          $purchasetrans->prescriptionid = $purchasetemps->prescriptionid;
          $purchasetrans->itemdesc = $purchasetemps->itemdesc;
          $purchasetrans->qty = $purchasetemps->qty;
          $qty = $purchasetemps->qty;
          $purchasetrans->save();

          $prescriptions = Prescription::where('prescriptionid', '=', $purchasetemps->prescriptionid)->first(); 
          $dosagecode = $prescriptions->dosagecode;
          if($dosagecode == "OID"){
                $noofdays = $qty;
          }
          if($dosagecode == "BID"){
                $noofdays = ($qty / 2);
          }
          if($dosagecode == "TID"){
                $noofdays = ($qty / 3);
          }
          if($dosagecode == "FID"){
                $noofdays = ($qty / 4);
          }
          if($dosagecode == "SID"){
                $noofdays = ($qty / 6);
          }

          $noofdays = floor($noofdays);

          $refilldate = $prescriptions->refilldate;

          if(! empty($refilldate)){
              if($transdate > $refilldate){
                  $refilldate = date('Y-m-d', strtotime($transdate. ' + '. $noofdays. ' days'));
                  $reminderdate = date('Y-m-d', strtotime($refilldate. ' - 3 days'));
                  $prescriptions->qtysold = $qty;
                  $prescriptions->lasttransdate = $transdate;
                  $prescriptions->lasttranstime = $transtime;
                  $prescriptions->branchid = $branchid;
                  $prescriptions->reminderdate = $reminderdate;
                  $prescriptions->refilldate = $refilldate;
                  $prescriptions->save(); 
              } else {
                  $refilldate2 = strtotime($refilldate);
                  $transdate2 = strtotime($transdate);
                  $datediff = $refilldate2 - $transdate2;
                  $datediff =  round($datediff / (60 * 60 * 24));
                  //$datediff = $datediff  + 1;
                  if($dosagecode == "OID"){
                        $remaining = $datediff;
                  }
                  if($dosagecode == "BID"){
                        $remaining = ($datediff * 2);
                  }
                  if($dosagecode == "TID"){
                        $remaining = ($datediff * 3);
                  }
                  if($dosagecode == "FID"){
                        $remaining = ($datediff * 4);
                  }
                  if($dosagecode == "SID"){
                        $remaining = ($datediff * 6);
                  } 

                  $refilldate = date('Y-m-d', strtotime($refilldate. ' + '. $noofdays. ' days'));
                  $reminderdate = date('Y-m-d', strtotime($refilldate. ' - 3 days'));
                  $prescriptions->qtysold = $qty;
                  $prescriptions->remaining = $remaining;
                  $prescriptions->lasttransdate = $transdate;
                  $prescriptions->lasttranstime = $transtime;
                  $prescriptions->branchid = $branchid;
                  $prescriptions->reminderdate = $reminderdate;
                  $prescriptions->refilldate = $refilldate;
                  $prescriptions->save(); 
              }   
          } else {

              $refilldate = date('Y-m-d', strtotime($transdate. ' + '. $noofdays. ' days'));
              $reminderdate = date('Y-m-d', strtotime($refilldate. ' - 3 days'));
              $prescriptions->qtysold = $qty;
              $prescriptions->lasttransdate = $transdate;
              $prescriptions->lasttranstime = $transtime;
              $prescriptions->branchid = $branchid;
              $prescriptions->reminderdate = $reminderdate;
              $prescriptions->refilldate = $refilldate;
              $prescriptions->save();            
          }

          if($reminders = Reminder::where('patientno', '=', $request->vpatientno)->where('send_at', $reminderdate)->first()){
              $reminders->patientno = $request->vpatientno;
              $reminders->title = "Refill Reminder for ". $patients->fullname;
              $reminders->description = "Stay Well! Get Well! Your Medicine that you bought from us is due for a Refill. We are here to serve you better!";
              $starttime = date('h:i:s', strtotime("07:00:00"));
              $endtime = date('h:i:s', strtotime("22:00:00"));
              $reminders->start = $refilldate. " ". $starttime;
              $reminders->end = $refilldate. " ". $endtime;
              $reminders->send_at = $reminderdate;
              $reminders->branchid = $branchid;
              $reminders->save();

          } else {
              $reminders = new Reminder;  
              $reminders->patientno = $request->vpatientno;
              $reminders->title = "Refill Reminder for ". $patients->fullname;
              $reminders->description = "Stay Well! Get Well! Your Medicine that you bought from us is due for a Refill. We are here to serve you better!";
              $starttime = date('h:i:s', strtotime("07:00:00"));
              $endtime = date('h:i:s', strtotime("22:00:00"));
              $reminders->start = $refilldate. " ". $starttime;
              $reminders->end = $refilldate. " ". $endtime;
              $reminders->send_at = $reminderdate;
              $reminders->branchid = $branchid;
              $reminders->save();            
          }

        }

        $purchasetemps = DB::table('purchasetemps')->where('userid','=', $userid)->delete();

        if(DB::table('patbranches')->where('branchid','=', $branchid)->first()){

        } else {
            $patbranches = new Patbranch;
            $patbranches->patientno = $request->vpatientno;
            $patbranches->branchid = $branchid;
            $patbranches->save();
        }

        $email = $patients->emailadd;
        $name = $patients->fullname;
        if(!empty($patients->emailadd)){
                    Mail::send('email', [
                            'name' => $patients->fullname,
                            'email' => $patients->emailadd,
                            'comment' => "Welcome to St Joseph Drug. We are happy to serve you better!" ],
                            function ($message) use($email, $name){
                                    $message->from('marketing@stjosephdrug.com');
                                    $message->to($email, $name)
                                    ->subject('Welcome to St. Joseph Drug');
                    });             

            try{
         
            }
            catch(\Exception $e){
                // Never reached
            }
        }


        return redirect()->route('profiling.transactions.create'); 

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if($purchases = DB::table('purchases')->where('purchaseid', $id)->first()) {
            $patients = DB::table('patients')->where('patientno', $purchases->patientno)->first();
            $branches = DB::table('branches')->where('branchid', $purchases->branchid)->first();
        } else {
            return abort(404);
        }

        return view('profiling.transactions.show', compact('purchases', 'patients', 'branches')); 
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    public function fetchprescriptions(Request $request)
    {


         if(request()->ajax())
         {

               $data = DB::table('prescriptions')
                 ->select('prescriptions.*', 'dosages.dosage', 'branches.branch')
                 ->leftJoin('dosages', 'dosages.dosagecode', '=', 'prescriptions.dosagecode')
                 ->leftJoin('branches', 'branches.branchid', '=', 'prescriptions.branchid')
                 ->where('prescriptions.patientno', '=',$request->patientno)
                 ->get();

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {
                
                $token =  csrf_token();                  
                //return "<a title='Delete' href='#' onclick='EditDependent()' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-edit'></i> Delete</a> 
                //        <a title='Delete' href='#' onclick='DeleteDependent(this)' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";
                //return "<a title='Delete' href='#' onclick='DeleteCertification(this)' type='button' class='btn btn-xs btn-danger' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";    
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='#' onclick='BuyData(this)' id='$row->prescriptionid' data-bs-toggle='modal' data-bs-target='#buymodal'><i class='fas fa-shopping-cart text-blue'></i><small> Buy</small></a>
                              <a class='dropdown-item' href='#' onclick='EditData(this)' id='$row->prescriptionid' data-bs-toggle='modal' data-bs-target='#editmodal'><i class='fas fa-edit text-green'></i><small> Edit</small></a>
                              <a title='Delete' href='#' onclick='DeletePrescription(this)' type='button' class='btn btn-xs btn-danger' id=".$row->prescriptionid. "><i class='fa fa-trash'></i> Delete</a>
                            </div>
                        </div>";                 
                
            })
            ->editColumn('lasttransdate', '{{ date("m/d/Y", strtotime($lasttransdate)) }} ')
            ->editColumn('refilldate', '{{ date("m/d/Y", strtotime($refilldate)) }} ')
       
            ->removeColumn('password')
            ->make(true);

         }

    }

    public function savepatient(Request $request)
    {
        if($counters = DB::table('counters')->where('appname', 'patients')->first()){
            $appyear = $counters->appyear;
            $appctr = $counters->appctr;
            $curyear = date('y');

            if($appyear == $curyear){
                $appctr = $appctr + 1;
                $controlno = $appyear. "-". str_pad($appctr, 6, "0", STR_PAD_LEFT);
                $counters = Counter::where('appname', '=', "patients")->first();
                $counters->appyear = $appyear;
                $counters->appctr = $appctr;
                $counters->save();
            } else {
                $appctr = 1;
                $controlno = $curyear. "-". str_pad($appctr, 6, "0", STR_PAD_LEFT);
                $counters = Counter::where('appname', '=', "patients")->first();
                $counters->appyear = $curyear;
                $counters->appctr = $appctr;
                $counters->save();
            }
        } else {
            $curyear = date('y');
            $appctr = 1;
            $controlno = $curyear. "-". str_pad($appctr, 6, "0", STR_PAD_LEFT);
            $counters = new Counter; 
            $counters->appname = "patients";
            $counters->appyear = $curyear;
            $counters->appctr = $appctr;
            $counters->save();
        }

        $patients = new Patient;
        $patients->patientno = $controlno;
        $patients->lname = $request->lname; 
        $patients->fname = $request->fname;
        $patients->mname = $request->mname;
        if(!empty($request->mname)){
            $patients->fullname = $request->fname. " ". substr($request->mname, 0, 1). ". ". $request->lname;
            $patients->fullname2 = $request->lname. ", ". $request->fname. " ". substr($request->mname, 0, 1). ".";            
        } else {
            $patients->fullname = $request->fname. " ". $request->lname;
            $patients->fullname2 = $request->lname. ", ". $request->fname;            
        }


        $patients->address = $request->address;
        $patients->gender = $request->gender;
        $patients->mobileno = $request->mobileno;
        $patients->telno = $request->telno;
        $patients->emailadd = $request->emailadd;
        if(!empty($request->birthdate)){
            $patients->birthdate = $request->birthdate;
        }
        $patients->allergies = $request->allergies;
        $patients->conditions = $request->conditions;
        $patients->scidno = $request->scidno;
        $patients->save();

        return response()->json(['success'=>'success']);
    }  

    public function saveprescription(Request $request)
    {

        $prescriptions = new Prescription;
        $prescriptions->patientno = $request->patientno;
        $prescriptions->itemdesc = $request->itemdesc; 
        $prescriptions->qtyprescribed = $request->qtyprescribed;
        $prescriptions->qtysold = 0;
        $prescriptions->remaining = 0;
        $prescriptions->dosagecode = $request->dosagecode;
        $prescriptions->doctor = $request->doctor;
        $prescriptions->hospital = $request->hospital;

        //$qtysold = $request->qtysold;
        //$dosagecode = $request->dosagecode;
        $prescriptions->save();
        $prescriptionid = $prescriptions->prescriptionid;

        $userid = auth()->user()->id;
        $purchasetemps = new Purchasetemp;
        $purchasetemps->userid = $userid;
        $purchasetemps->itemdesc = $request->itemdesc; 
        $purchasetemps->prescriptionid = $prescriptionid; 
        $purchasetemps->qty = $request->qtysold;
        $purchasetemps->save();


        return response()->json(['success'=>'success']);
    } 

    public function fetchpurchasetemps(Request $request)
    {

        $userid = auth()->user()->id;
        if(request()->ajax())
        {
              $userid = auth()->user()->id;
               $data = DB::table('purchasetemps')
                 ->select('*')
                 ->where('userid', '=',$userid)
                 ->get();

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {
                
                $token =  csrf_token();                  
                //return "<a title='Delete' href='#' onclick='EditDependent()' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-edit'></i> Delete</a> 
                //        <a title='Delete' href='#' onclick='DeleteDependent(this)' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";
                //return "<a title='Delete' href='#' onclick='DeleteCertification(this)' type='button' class='btn btn-xs btn-danger' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";    
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='#' onclick='EditPurchasetemp(this)' id='$row->id' data-bs-toggle='modal' data-bs-target='#editpurchasemodal'><i class='fas fa-edit text-green'></i><small> Edit</small></a>
                              <a title='Delete' href='#' onclick='DeletePurchasetemp(this)' type='button' class='btn btn-xs btn-danger' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a>
                            </div>
                        </div>";                 
                
            })
            ->editColumn('id', 'ID: {{$id}}')            
            ->removeColumn('password')
            ->make(true);

        }

    }

    public function getBuyItem(Request $request) 
    {

        $id = $request->id;

        $prescriptions = DB::table('prescriptions')->where('prescriptionid', $id)->first();
        $itemdesc = $prescriptions->itemdesc;
        $qtyprescribed = $prescriptions->qtyprescribed;
        $dosagecode = $prescriptions->dosagecode;
        $dosages = DB::table('dosages')->where('dosagecode', $dosagecode)->first();
        $dosage = $dosages->dosage;

        echo $id. "|". $itemdesc. "|". $qtyprescribed. "|". $dosagecode. "|". $dosage;

    } 

    public function savepurchasetemps(Request $request)
    {

        $userid = auth()->user()->id;
        $purchasetemps = new Purchasetemp;
        $purchasetemps->userid = $userid;
        $purchasetemps->prescriptionid = $request->prescriptionid;
        $purchasetemps->itemdesc = $request->itemdesc; 
        $purchasetemps->qty = $request->qty;
        $purchasetemps->save();


        return response()->json(['success'=>'success']);
    }   

    public function getPrescription(Request $request) 
    {

        $id = $request->id;

        $prescriptions = DB::table('prescriptions')->where('prescriptionid', $id)->first();
        $itemdesc = $prescriptions->itemdesc;
        $qtyprescribed = $prescriptions->qtyprescribed;
        $dosagecode = $prescriptions->dosagecode;
        $refilldate = $prescriptions->refilldate;
        $doctor = $prescriptions->doctor;
        $hospital = $prescriptions->hospital;
        $dosages = DB::table('dosages')->where('dosagecode', $dosagecode)->first();
        $dosage = $dosages->dosage;


        echo $id. "|". $itemdesc. "|". $qtyprescribed. "|". $dosagecode. "|". $dosage. "|". $refilldate. "|". $doctor. "|". $hospital;

    } 

    public function updateprescription(Request $request)
    {

        $prescriptions = Prescription::where('prescriptionid', '=', $request->prescriptionid)->first(); 
        $prescriptions->itemdesc = $request->itemdesc; 
        $prescriptions->qtyprescribed = $request->qtyprescribed;
        $prescriptions->dosagecode = $request->dosagecode;
        $prescriptions->refilldate = $request->refilldate;
        $prescriptions->doctor = $request->doctor;
        $prescriptions->hospital = $request->hospital;
        $prescriptions->save();


        return response()->json(['success'=>'success']);
    }   

    public function deleteprescriptions(Request $request)
    {
        
        $id = $request->id;
        $prescriptions = DB::table('prescriptions')->where('prescriptionid', '=', $id)->delete();

    }

    public function getPurchasetemp(Request $request) 
    {

        $id = $request->id;

        $purchasetemps = DB::table('purchasetemps')->where('id', $id)->first();
        $prescriptionid = $purchasetemps->prescriptionid;
        $itemdesc = $purchasetemps->itemdesc;
        $qty = $purchasetemps->qty;



        echo $id. "|". $prescriptionid. "|". $itemdesc. "|". $qty;

    }   

    public function Updatepurchasetemp(Request $request)
    {

        $purchasetemps = Purchasetemp::where('id', '=', $request->id)->first(); 
        $purchasetemps->itemdesc = $request->itemdesc; 
        $purchasetemps->qty = $request->qty;
        $purchasetemps->save();


        return response()->json(['success'=>'success']);
    } 

    public function deletepurchasetemp(Request $request)
    {
        
        $id = $request->id;
        $prescriptions = DB::table('purchasetemps')->where('id', '=', $id)->delete();

    }

    public function Canceltransactions(Request $request)
    {
        
        $userid = auth()->user()->id;
        $purchasetemps = DB::table('purchasetemps')->where('userid', '=', $userid)->delete();

    }

    public function clearpurchasetemps(Request $request) 
    {
      $userid = auth()->user()->id;
      $deletepurchasetemps = DB::table('purchasetemps')->where('userid','=', $userid)->delete();
    }

    public function fetchpurchasetrans(Request $request)
    {

        $purchaseid = $request->purchaseid;
        if(request()->ajax())
        {
              $userid = auth()->user()->id;
               $data = DB::table('purchasetrans')
                 ->select('*')
                 ->where('purchaseid', '=',$purchaseid)
                 ->get();

             return datatables()->of($data)        
            ->addColumn('action', function ($row) {
                
                $token =  csrf_token();                  
                //return "<a title='Delete' href='#' onclick='EditDependent()' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-edit'></i> Delete</a> 
                //        <a title='Delete' href='#' onclick='DeleteDependent(this)' type='button' class='m-r-15 crm-action-edit text-muted' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";
                //return "<a title='Delete' href='#' onclick='DeleteCertification(this)' type='button' class='btn btn-xs btn-danger' id=".$row->id. "><i class='fa fa-trash'></i> Delete</a> ";    
                return "<div class='btn-group'>
                            <button  data-bs-toggle='dropdown' data-boundary='viewport' class='btn-xs btn-primary dropdown-toggle' type='button'>
                            <small>Action</small> 
                            <span class='caret'></span></button>

                            <div class='dropdown-menu' >
                              <a class='dropdown-item' href='#' onclick='EditPurchasetemp(this)' id='$row->id' data-bs-toggle='modal' data-bs-target='#editpurchasemodal'><i class='fas fa-edit text-green'></i><small> Edit</small></a>
                            </div>
                        </div>";                 
                
            })
            ->editColumn('id', 'ID: {{$id}}')            
            ->removeColumn('password')
            ->make(true);

        }

    }    

}
